## AWS AutoScaling API Library

This is a sister package to `@aws-cdk/aws-autoscaling`. It contains interface
definitions that cannot be placed inside the other package to avoid dependency cycles.

It does not need to be used directly.
